# Generated by roxygen2: do not edit by hand

S3method(logLik,mix)
S3method(logLik,mvn)
S3method(mean,mix)
S3method(mean,mvn)
S3method(print,mix)
S3method(print,mvn)
S3method(vcov,mix)
S3method(vcov,mvn)
export(ChooseK)
export(ClustQual)
export(CombineMIs)
export(FitGMM)
export(GenImputation)
export(PartitionData)
export(ReconstituteData)
export(rGMM)
exportClasses(mix)
exportClasses(mvn)
importFrom(Rcpp,sourceCpp)
useDynLib(MGMM, .registration = TRUE)
